sqlobject.tests.test_groupBy module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_groupBy module

class `sqlobject.tests.test_groupBy.` `GroupbyTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = groupby_test
  property `name`
  `q` = groupby_test
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_groupBy.GroupbyTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'groupby_test'

`sqlobject.tests.test_groupBy.` `test_groupBy`()

`sqlobject.tests.test_groupBy.` `test_groupBy_list`()